@@ -141,7 +141,7 @@ errno_t e_linux_readdir(
 
 	errno_t err;
 	kern_return_t kr;
-	int intr, nread;
+	int nread;
 	struct dirent *de;
 
 	struct {
@@ -252,6 +252,8 @@ errno_t e_linux_sigprocmask(int how, const sigset_t *set, sigset_t *oset)
 {
 	errno_t err;
 	int newhow = 0;
+	sigset_t nset;
+	sigset_t *nset_p = (sigset_t *)NULL;
 
 	/* Convert how from Linux to native */
 	switch (how) {
@@ -265,9 +267,12 @@ errno_t e_linux_sigprocmask(int how, const sigset_t *set, sigset_t *oset)
 		newhow = SIG_SETMASK;
 		break;
 	}
-	if (set)
-	    *set = sigmask_linux_to_bsd(*set);
-	err = e_sigprocmask(newhow, set, oset);
+	if (set) {
+	  	nset = sigmask_linux_to_bsd(*set);
+		nset_p = &nset;
+	}
+	
+	err = e_sigprocmask(newhow, nset_p, oset);
 	if (!err && oset)
 	    *oset = sigmask_bsd_to_linux(*oset);
 	return err;
