@@ -66,6 +66,7 @@
  *	@(#)subr_prf.c	8.3 (Berkeley) 1/21/94
  */
 
+#include "osfmach3.h"
 #include "second_server.h"
 
 #include <sys/param.h>
@@ -110,6 +111,10 @@ void kprintf __P((const char *fmt, int flags, struct tty *tp, va_list ap));
 
 int consintr = 1;			/* Ok to handle console interrupts? */
 
+#if OSFMACH3
+extern security_token_t security_id;
+#endif
+
 #if	SECOND_SERVER
 extern	int 	second_server;
 #endif	/* SECOND_SERVER */
@@ -712,7 +717,13 @@ dprintf(const char *fmt, ...)
 		 * Open the console
 		 */
 		rc = device_open(device_server_port,
+#if OSF_LEDGERS
+				 MACH_PORT_NULL,
+#endif
 				 D_READ|D_WRITE,
+#if OSFMACH3
+				 security_id,
+#endif
 				 "console",
 				 &dprintf_console_port);
 		if (rc != KERN_SUCCESS)
@@ -724,6 +735,9 @@ dprintf(const char *fmt, ...)
 	va_end(ap);
 
 	bp = dprintf_buf;
+	if (dprintf_buf[len] == '\n')
+	  dprintf_buf[ ++len ] = '\r';
+
 	while (len > 0) {
 	    (void) device_write_inband(dprintf_console_port,
 #define _min(x,y) (((x)<(y))?(x):(y))
@@ -746,7 +760,13 @@ dgetc()
 		 * Open the console
 		 */
 		rc = device_open(device_server_port,
+#if OSF_LEDGERS
+				 MACH_PORT_NULL,
+#endif
 				 D_READ|D_WRITE,
+#if OSFMACH3
+				 security_id,
+#endif
 				 "console",
 				 &dprintf_console_port);
 		if (rc != KERN_SUCCESS)
@@ -760,3 +780,37 @@ dgetc()
 	    panic("gets: device_read_inband");
 
 }
+
+/* Prompt on console and read string.  size includes nul */
+dget_string(const char *prompt, char *buf, int size)
+{
+  int count = 0;
+  int c;
+
+  if (prompt)
+    dprintf(prompt);
+
+  while (count < size) {
+    c = dgetc();
+    switch (c) {
+    case '.':
+    case '\n':
+    case '\r':
+      buf[count] = '\0';
+      return;
+    case '\b':
+    case '\177':
+      if (count <= 0)
+	continue;
+      dprintf("\b \b");
+      count--;
+      break;
+    default:
+      buf[count] = c;
+      dprintf("%c", c);
+      count++;
+      break;
+    }
+  }
+  buf[count] = '\0';
+}
