@@ -334,7 +334,7 @@ mach_error_t s_sendmsg(
 	int		cmsglen,
 	char		*data,
 	int		datalen,
-	int		*retsize)
+	size_t		*retsize)
 {
 	struct file *fp;
 	struct uio auio;
@@ -402,7 +402,7 @@ mach_error_t s_recvmsg(
 	int		*cmsglen,	/* IN/OUT */
 	char		*data,		/* OUT */
 	int		datalen,
-	int		*retsize)	/* OUT */
+	size_t		*retsize)	/* OUT */
 {
 	struct file *fp;
 	struct uio auio;
