@@ -1479,6 +1479,7 @@ fchown(p, uap, retval)
 	return (error);
 }
 
+#if 0
 /*
  * Set the access and modification times of a file.
  */
@@ -1492,6 +1493,15 @@ utimes(p, uap, retval)
 	register struct utimes_args *uap;
 	int *retval;
 {
+#else
+mach_error_t s_utimes(
+	struct proc *p,
+	char	*path,
+	struct	timeval *tptr,
+	int *retval)
+{
+
+#endif
 	register struct vnode *vp;
 	struct timeval tv[2];
 	struct vattr vattr;
@@ -1499,13 +1509,13 @@ utimes(p, uap, retval)
 	struct nameidata nd;
 
 	VATTR_NULL(&vattr);
-	if (uap->tptr == NULL) {
+	if (tptr == NULL) {
 		microtime(&tv[0]);
 		tv[1] = tv[0];
 		vattr.va_vaflags |= VA_UTIMES_NULL;
-	} else if (error = copyin((caddr_t)uap->tptr, (caddr_t)tv, sizeof (tv)))
+	} else if (error = copyin((caddr_t)tptr, (caddr_t)tv, sizeof (tv)))
   		return (error);
-	NDINIT(&nd, LOOKUP, FOLLOW, UIO_USERSPACE, uap->path, p);
+	NDINIT(&nd, LOOKUP, FOLLOW, UIO_USERSPACE, path, p);
 	if (error = namei(&nd))
 		return (error);
 	vp = nd.ni_vp;
