@@ -58,47 +58,95 @@ kern_return_t
 bsd_write_short(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			fileno,
-	char *			data,
+	char			*data,
 	mach_msg_type_number_t	data_count,
-	int			*amount_written)	/* OUT */
+	size_t			*nwritten)	/* OUT */
 {
 	START_SERVER(SYS_write, 3)
 
 	arg[0] = fileno;
 	arg[1] = (integer_t)data;
 	arg[2] = (integer_t)data_count;
-	error = write(p, arg, amount_written);
+	error = s_write(p, arg, nwritten);
 
 	END_SERVER(SYS_write)
 }
 
 kern_return_t
 bsd_write_long(
-	mach_port_t	proc_port,
+	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
-	int		fileno,
-	char *		data,
+	int			fileno,
+	char			*data,
 	mach_msg_type_number_t	data_count,
-	int		*amount_written)	/* out */
+	size_t			*nwritten)	/* OUT */
 {
 	START_SERVER(SYS_write, 3)
 
 	arg[0] = fileno;
 	arg[1] = (integer_t)data;
 	arg[2] = (integer_t)data_count;
-	error = write(p, arg, amount_written);
+	error = s_write(p, arg, nwritten);
 
 	END_SERVER_DEALLOC(SYS_write, data, data_count)
 }
 
+kern_return_t
+bsd_read_short(
+	mach_port_t		proc_port,
+	mach_port_seqno_t	seqno,
+	int			fileno,
+	int			datalen,
+	size_t			*nread,		/* OUT */
+	char 			*data,		/* OUT */
+	mach_msg_type_number_t	*data_count)	/* max in/OUT */
+{
+	START_SERVER(SYS_read, 3);
+
+	error = KERN_SUCCESS;
+	if (datalen < 0 || datalen > *data_count) {
+		error = EINVAL;
+	} else {
+		arg[0] = fileno;
+		arg[1] = (integer_t) data;
+		arg[2] = (integer_t) datalen;
+		error = s_read(p, arg, nread);
+	}
+	if (error == KERN_SUCCESS)
+	    *data_count = *nread;
+
+	END_SERVER(SYS_read)
+}
+
+kern_return_t
+bsd_read_long(
+	mach_port_t		proc_port,
+	mach_port_seqno_t	seqno,
+	int			fileno,
+	int			datalen,
+	size_t			*nread,		/* OUT */
+	char			**data,		/* OUT dealloc */
+	mach_msg_type_number_t	*data_count)	/* OUT */
+{
+	START_SERVER(SYS_read, 3);
+
+	*data_count = round_page(datalen);
+	error = vm_allocate(mach_task_self(), (vm_offset_t *) data,
+			    *data_count, TRUE);
+	if (error == KERN_SUCCESS) {
+		arg[0] = fileno;
+		arg[1] = (integer_t) *data;
+		arg[2] = (integer_t) datalen;
+		error = s_read(p, arg, nread);
+	}
+	END_SERVER_DEALLOC_ON_ERROR(SYS_read, (*data), (*data_count));
+}
+
 kern_return_t
 bsd_select(
 	mach_port_t	proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
 	int		nd,
 	fd_set		*in_set,	/* in/out */
 	fd_set		*ou_set,	/* in/out */
@@ -130,7 +178,6 @@ kern_return_t
 bsd_chdir(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	char			*fname,
 	mach_msg_type_number_t	fname_count)
 {
@@ -147,7 +194,6 @@ kern_return_t
 bsd_chroot(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	char			*fname,
 	mach_msg_type_number_t	fname_count)
 {
@@ -164,11 +210,10 @@ kern_return_t
 bsd_open(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	char			*fname,
-	mach_msg_type_number_t	fname_count,
 	int			mode,
 	int			crtmode,
+	char			*fname,
+	mach_msg_type_number_t	fname_count,
 	int			*fileno)	/* OUT */
 {
 	START_SERVER(SYS_open, 3)
@@ -186,11 +231,10 @@ kern_return_t
 bsd_mknod(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	char			*fname,
-	mach_msg_type_number_t	fname_count,
 	int			fmode,
-	int			dev)
+	int			dev,
+	char			*fname,
+	mach_msg_type_number_t	fname_count)
 {
 	START_SERVER(SYS_mknod, 3)
 
@@ -207,7 +251,6 @@ kern_return_t
 bsd_link(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	char			*target,
 	mach_msg_type_number_t	target_count,
 	char			*linkname,
@@ -227,7 +270,6 @@ kern_return_t
 bsd_symlink(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	char			*target,
 	mach_msg_type_number_t	target_count,
 	char			*linkname,
@@ -247,7 +289,6 @@ kern_return_t
 bsd_unlink(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	char			*fname,
 	mach_msg_type_number_t	fname_count)
 {
@@ -264,10 +305,9 @@ kern_return_t
 bsd_access(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
+	int			fmode,
 	char			*fname,
-	mach_msg_type_number_t	fname_count,
-	int			fmode)
+	mach_msg_type_number_t	fname_count)
 {
 	START_SERVER(SYS_access, 2)
 
@@ -283,10 +323,9 @@ kern_return_t
 bsd_readlink(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
+	int			count,
 	path_name_t		name,
 	mach_msg_type_number_t	name_count,
-	int			count,
 	char			*buf,		/* pointer to OUT array */
 	mach_msg_type_number_t	*bufCount)	/* out */
 {
@@ -305,18 +344,14 @@ kern_return_t
 bsd_utimes(
 	mach_port_t	proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
+	struct timeval	*times,
 	char		*fname,
-	mach_msg_type_number_t	fname_count,
-	struct timeval	*times)
+	mach_msg_type_number_t	fname_count)
 {
 	START_SERVER(SYS_utimes, 2)
 
 	TRACE(("(%s)",fname));
-	arg[0] = (integer_t)fname;
-	arg[1] = (integer_t)times;
-	error = utimes(p, arg, 0);
-
+	error = s_utimes(p, fname, times, 0);
 	END_SERVER(SYS_utimes)
 }
 
@@ -324,7 +359,6 @@ kern_return_t
 bsd_rename(
 	mach_port_t	proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
 	char		*from,
 	mach_msg_type_number_t	from_count,
 	char		*to,
@@ -344,10 +378,9 @@ kern_return_t
 bsd_mkdir(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
+	int			dmode,
 	char			*name,
-	mach_msg_type_number_t		name_count,
-	int			dmode)
+	mach_msg_type_number_t	name_count)
 {
 	START_SERVER(SYS_mkdir, 2)
 
@@ -363,7 +396,6 @@ kern_return_t
 bsd_rmdir(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	char			*name,
 	mach_msg_type_number_t		name_count)
 {
@@ -380,9 +412,8 @@ kern_return_t
 bsd_fork(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	thread_state_t		new_state,
-	mach_msg_type_number_t		new_state_count,
+	mach_msg_type_number_t	new_state_count,
 	int			*child_pid)	/* OUT */
 {
 	START_SERVER(SYS_fork, 2)
@@ -396,7 +427,6 @@ kern_return_t
 bsd_vfork(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	thread_state_t		new_state,
 	mach_msg_type_number_t		new_state_count,
 	int			*child_pid)	/* OUT */
@@ -417,7 +447,6 @@ kern_return_t
 bsd_acct(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	boolean_t		acct_on,
 	char			*fname,
 	mach_msg_type_number_t		fname_count)
@@ -437,7 +466,6 @@ kern_return_t
 bsd_setgroups(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			gidsetsize,
 	gidset_t		gidset)
 {
@@ -455,7 +483,6 @@ kern_return_t
 bsd_setrlimit(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			which,
 	struct rlimit		*lim)
 {
@@ -464,7 +491,7 @@ bsd_setrlimit(
 	arg[0] = which;
 	arg[1] = (integer_t)lim;
 
-	error = setrlimit(p, arg, 0);
+	error = s_setrlimit(p, arg, 0);
 
 	END_SERVER(SYS_setrlimit)
 }
@@ -473,7 +500,6 @@ kern_return_t
 bsd_sigstack(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	boolean_t		have_nss,
 	struct sigstack		nss,
 	struct sigstack		*oss)		/* OUT */
@@ -496,7 +522,6 @@ kern_return_t
 bsd_settimeofday(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	boolean_t		have_tv,
 	struct timeval		tv,
 	boolean_t		have_tz,
@@ -507,7 +532,7 @@ bsd_settimeofday(
 	arg[0] = (have_tv) ? (integer_t)&tv : 0;
 	arg[1] = (have_tz) ? (integer_t)&tz : 0;
 
-	error = settimeofday(p, arg, 0);
+	error = s_settimeofday(p, arg, 0);
 
 	END_SERVER(SYS_settimeofday)
 }
@@ -516,7 +541,6 @@ kern_return_t
 bsd_adjtime(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	struct timeval		delta,
 	struct timeval		*olddelta)
 {
@@ -525,7 +549,7 @@ bsd_adjtime(
 	arg[0] = (integer_t)&delta;
 	arg[1] = (integer_t)olddelta;
 
-	error = adjtime(p, arg, 0);
+	error = s_adjtime(p, arg, 0);
 
 	END_SERVER(SYS_adjtime)
 }
@@ -534,7 +558,6 @@ kern_return_t
 bsd_setitimer(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			which,
 	boolean_t		have_itv,
 	struct itimerval	*oitv,		/* OUT */
@@ -555,7 +578,6 @@ kern_return_t
 bsd_sethostname(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	char			*hostname,
 	int			len)
 {
@@ -577,7 +599,6 @@ kern_return_t
 bsd_bind(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			s,
 	sockarg_t		name,
 	mach_msg_type_number_t	namelen)
@@ -593,7 +614,6 @@ kern_return_t
 bsd_connect(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			s,
 	sockarg_t		name,
 	mach_msg_type_number_t	namelen)
@@ -609,7 +629,6 @@ kern_return_t
 bsd_setsockopt(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			s,
 	int			level,
 	int			name,
@@ -629,7 +648,6 @@ kern_return_t
 bsd_getsockopt(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			s,
 	int			level,
 	int			name,
@@ -649,7 +667,6 @@ kern_return_t
 bsd_table_set(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,	/* out */
 	int			id,
 	int			index,
 	int			lel,
@@ -675,7 +692,6 @@ kern_return_t
 bsd_table_get(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,	/* out */
 	int			id,
 	int			index,
 	int			lel,
@@ -712,7 +728,7 @@ bsd_table_get(
 	/* { for electric-c */
 	}
         unix_release();
-	error = end_server_op(p, error, interrupt);
+	error = end_server_op(p, error, (boolean_t *)0);
 	if (error) {
 	    (void) vm_deallocate(mach_task_self(),
 				 (vm_offset_t) *addr,
@@ -739,16 +755,18 @@ bsd_emulator_error(
 	printf("emulator [%d] %s\n", pid, error_message);
 	return KERN_SUCCESS;
 }
+
 kern_return_t
 bsd_readwrite(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	boolean_t		which,
 	int			fileno,
 	int			size,
 	int			*amount)
 {
+	panic("bsd_readwrite");
+#if 0
 #if	MAP_UAREA
 	if (which != 0 && which != 1)
 		return (EINVAL);
@@ -770,6 +788,7 @@ bsd_readwrite(
 #else	MAP_UAREA
 	return (EINVAL);
 #endif	MAP_UAREA
+#endif
 }
 
 kern_return_t
@@ -804,7 +823,6 @@ kern_return_t
 bsd_maprw_request_it(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	register int		fileno)
 {
 #if	MACH_NBC && MAP_UAREA
@@ -823,7 +841,6 @@ kern_return_t
 bsd_maprw_release_it(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	register int		fileno)
 {
 #if	MACH_NBC && MAP_UAREA
@@ -841,7 +858,6 @@ kern_return_t
 bsd_maprw_remap(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	register int		fileno,
 	int			offset,
 	int			size)
@@ -906,8 +922,6 @@ bsd_setattr(
 	int			fileno,
 	vattr_t			vattr)
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1008, 2);
 	TRACE(("(x%x)", fileno));
 	error = setattr(p, fileno, &vattr);
@@ -921,8 +935,6 @@ bsd_getattr(
 	int			fileno,
 	vattr_t			*vattr)		/* OUT */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1009, 2);
 	TRACE(("(x%x)", fileno));
 	error = getattr(p, fileno, vattr);
@@ -933,13 +945,11 @@ kern_return_t
 bsd_path_setattr(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	char			*path,
-	mach_msg_type_number_t		path_count,
 	boolean_t		follow,
+	char			*path,
+	mach_msg_type_number_t	path_count,
 	vattr_t			vattr)
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1010, 2);
 	TRACE(("(%s,%d)", path, follow));
 	error = path_setattr(p, path, follow, &vattr);
@@ -950,15 +960,14 @@ kern_return_t
 bsd_path_getattr(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	char			*path,
-	mach_msg_type_number_t		path_count,
 	boolean_t		follow,
+	char			*path,
+	mach_msg_type_number_t	path_count,
 	vattr_t			*vattr)		/* OUT */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1011, 2);
 	TRACE(("(%s,%d)", path, follow));
+
 	error = path_getattr(p, path, follow, vattr);
 	END_SERVER(1011);
 }
@@ -969,13 +978,11 @@ bsd_execve(
 	mach_port_seqno_t	seqno,
 	vm_address_t		arg_addr,
 	vm_size_t		arg_size,
-	char			*fname,
-	mach_msg_type_number_t	fname_count,
 	int			arg_count,
-	int			env_count)
+	int			env_count,
+	char			*fname,
+	mach_msg_type_number_t	fname_count)
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1012, 5)
 
 	TRACE(("(%s)",fname));
@@ -992,41 +999,21 @@ kern_return_t
 bsd_after_exec(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	vm_address_t		*arg_addr,	/* OUT */
-	vm_size_t		*arg_size,	/* OUT */
-	int			*arg_count,	/* OUT */
-	int			*env_count,	/* OUT */
-	char			*emul_name,	/* OUT */
+	vm_address_t		*arg_addr,	  /* OUT */
+	vm_size_t		*arg_size,	  /* OUT */
+	int			*arg_count,	  /* OUT */
+	int			*env_count,	  /* OUT */
+	mach_port_t		*image_port,	  /* OUT move_send */
+	char			*emul_name,	  /* OUT */
 	mach_msg_type_number_t	*emul_name_count, /* OUT */
-	char			*fname,		/* OUT */
-	mach_msg_type_number_t	*fname_count,	/* OUT */
-	char			*cfname,	/* OUT */
-	mach_msg_type_number_t	*cfname_count,	/* OUT */
-	char			*cfarg,		/* OUT */
-	mach_msg_type_number_t	*cfarg_count,	/* OUT */
-	mach_port_t		*image_port)	/* OUT move_send */
+	char			*fname,		  /* OUT */
+	mach_msg_type_number_t	*fname_count,	  /* OUT */
+	char			*cfname,	  /* OUT */
+	mach_msg_type_number_t	*cfname_count,	  /* OUT */
+	char			*cfarg,		  /* OUT */
+	mach_msg_type_number_t	*cfarg_count)	  /* OUT */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
-#ifdef alpha
-	/* XXXXXXXX temporary */
-	mach_error_t	error;
-	integer_t	arg[4];
-        struct proc *p = proc_receive_lookup(proc_port, seqno);
-	proc_invocation_t pk = get_proc_invocation();
-        int was_serial = FALSE;
-	pk->k_p = p;
-
-	error = start_server_op(p, 1013);
-	if (error)
-	    return (error);
-	pk->k_reply_msg = 0;
-	if (was_serial)
-	    unix_master();
-	{
-#else
 	START_SERVER(1013, 4)
-#endif
 
 	error = after_exec(p,
 			   arg_addr, arg_size, arg_count, env_count,
@@ -1041,8 +1028,7 @@ bsd_after_exec(
 kern_return_t
 bsd_init_process(
 	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt)
+	mach_port_seqno_t	seqno)
 {
 	register int	error;
 	register struct proc *p;
@@ -1053,7 +1039,7 @@ bsd_init_process(
 
 	init_process(p);
 
-	return (end_server_op(p, error, interrupt));
+	return (end_server_op(p, error, (boolean_t *)0));
 }
 
 /* 
@@ -1077,7 +1063,6 @@ bsd_vm_map(
 	struct proc *p;
 	struct file *file;
 	mach_error_t error;
-	int xxxinterrupt = FALSE;
 	proc_invocation_t pk = get_proc_invocation();
 
 	p = port_object_receive_lookup(proc_port, seqno, POT_PROCESS);
@@ -1096,7 +1081,7 @@ bsd_vm_map(
 		error = EBADF;
 	}
 
-	return (end_server_op(p, error, &xxxinterrupt));
+	return (end_server_op(p, error, (boolean_t *)0));
 }
 
 /* 
@@ -1109,8 +1094,6 @@ bsd_fd_to_file_port(
 	int			fd,
 	mach_port_t		*port)		/* OUT move_send */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1015, 2);
 	TRACE(("(x%x)", fd));
 	error = fd_to_file_port(p, fd, port);
@@ -1125,14 +1108,12 @@ kern_return_t
 bsd_file_port_open(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	char			*fname,
-	mach_msg_type_number_t		fname_count,
 	int			mode,
 	int			crtmode,
+	char			*fname,
+	mach_msg_type_number_t	fname_count,
 	mach_port_t		*port)		/* OUT move_send */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1016, 4);
 	TRACE(("(%s)", fname));
 	panic("file_port_open unimplemented");
@@ -1148,8 +1129,6 @@ bsd_signal_port_register(
 	mach_port_seqno_t	seqno,
 	mach_port_t		sigport)
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(1018, 1);
 	mutex_lock(&p->p_lock);
 	/* 
@@ -1217,16 +1196,14 @@ bsd_sendmsg_short(
 	mach_port_seqno_t	seqno,
 	int			fileno,
 	int			flags,
+	char			*data,
+	mach_msg_type_number_t	data_count,
 	sockarg_t		to,
 	mach_msg_type_number_t	tolen,
 	sockarg_t		cmsg,
 	mach_msg_type_number_t	cmsg_length,
-	char			*data,
-	mach_msg_type_number_t	data_count,
-	int			*nsent)	/* OUT */
+	size_t			*nsent)	/* OUT */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(SYS_sendmsg, 6);
 
 	error = s_sendmsg(p, fileno, flags,
@@ -1234,7 +1211,6 @@ bsd_sendmsg_short(
 			  cmsg, cmsg_length,
 			  data, data_count,
 			  nsent);
-	    
 	END_SERVER(SYS_sendmsg)
 }
 
@@ -1244,16 +1220,14 @@ bsd_sendmsg_long(
 	mach_port_seqno_t	seqno,
 	int			fileno,
 	int			flags,
+	char			*data,
+	mach_msg_type_number_t	data_count,
 	sockarg_t		to,
 	mach_msg_type_number_t	tolen,
 	sockarg_t		cmsg,
 	mach_msg_type_number_t	cmsg_length,
-	char			*data,
-	mach_msg_type_number_t	data_count,
-	int			*nsent)	/* OUT */
+	size_t			*nsent)	/* OUT */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(SYS_sendmsg, 6);
 
 	error = s_sendmsg(p, fileno, flags,
@@ -1261,7 +1235,6 @@ bsd_sendmsg_long(
 			  cmsg, cmsg_length,
 			  data, data_count,
 			  nsent);
-	    
 	END_SERVER_DEALLOC(SYS_sendmsg, data, data_count);
 }
 
@@ -1273,6 +1246,7 @@ bsd_recvmsg_short(
 	int			flags,
 	int			*outflags,	/* OUT */
 	int			fromlen,
+	size_t			*nreceived,	/* OUT */
 	sockarg_t		from, 		/* OUT */
 	mach_msg_type_number_t	*from_count,	/* max in/OUT */
 	int			cmsglen,
@@ -1280,11 +1254,8 @@ bsd_recvmsg_short(
 	mach_msg_type_number_t	*cmsg_count,	/* max in/OUT */
 	int			datalen,
 	small_char_array	data,		/* OUT */
-	mach_msg_type_number_t	*data_count,	/* max in/OUT */
-	int			*nreceived)	/* OUT */
+	mach_msg_type_number_t	*data_count)	/* max in/OUT */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(SYS_recvmsg, 6);
 
 	error = KERN_SUCCESS;
@@ -1315,6 +1286,7 @@ bsd_recvmsg_long(
 	int			fileno,
 	int			flags,
 	int			*outflags,	/* OUT */
+	size_t			*nreceived,	/* OUT */
 	int			fromlen,
 	sockarg_t		from, 		/* OUT */
 	mach_msg_type_number_t	*from_count,	/* max in/OUT */
@@ -1323,11 +1295,8 @@ bsd_recvmsg_long(
 	mach_msg_type_number_t	*cmsg_count,	/* max in/OUT */
 	int			datalen,
 	char_array		*data,		/* OUT dealloc */
-	mach_msg_type_number_t	*data_count,	/* OUT */
-	int			*nreceived)	/* OUT */
+	mach_msg_type_number_t	*data_count)	/* OUT */
 {
-	boolean_t intr;
-	boolean_t *interrupt = &intr;
 	START_SERVER(SYS_recvmsg, 6);
 
 	error = KERN_SUCCESS;
@@ -1342,421 +1311,11 @@ bsd_recvmsg_long(
 	if (error == KERN_SUCCESS) {
 		error = vm_allocate(mach_task_self(),
 				    (vm_offset_t *) data, *data_count, TRUE);
-		if (error == KERN_SUCCESS)
-		    error = s_recvmsg(p, fileno, flags, &outflags,
-				      from, from_count, cmsg, cmsg_count,
-				      *data, datalen, nreceived);
+		if (error == KERN_SUCCESS) {
+			error = s_recvmsg(p, fileno, flags, &outflags,
+					  from, from_count, cmsg, cmsg_count,
+					  *data, datalen, nreceived);
+		}
 	}
-	END_SERVER(SYS_recvmsg)
+	END_SERVER_DEALLOC_ON_ERROR(SYS_recvmsg, (*data), (*data_count));
 }
-
-
-
-
-
-#define OBSOLETE 0
-
-#if	COMPAT_43 && OBSOLETE
-kern_return_t
-bsd_ogetsockname(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			fdes,
-	sockarg_t		asa,		/* OUT */
-	mach_msg_type_number_t	*alen)		/* OUT */
-{
-	START_SERVER(SYS_getsockname, 3)
-
-	*alen = sizeof(sockarg_t);
-
-	arg[0] = fdes;
-	arg[1] = (integer_t)asa;
-	arg[2] = (integer_t)alen;
-
-	error = ogetsockname(p, arg, 0);
-
-	END_SERVER(SYS_getsockname)
-}
-
-kern_return_t
-bsd_ogetpeername(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			fdes,
-	sockarg_t		asa,		/* OUT */
-	mach_msg_type_number_t	*alen)		/* OUT */
-{
-	START_SERVER(SYS_getpeername, 3)
-
-	*alen = sizeof(sockarg_t);
-
-	arg[0] = fdes;
-	arg[1] = (integer_t)asa;
-	arg[2] = (integer_t)alen;
-
-	error = ogetpeername(p, arg, 0);
-
-	END_SERVER(SYS_getpeername)
-}
-#endif	COMPAT_43
-
-#if OBSOLETE
-#if	COMPAT_43
-/*
- * in uipc_syscalls
- */
-kern_return_t
-bsd_send_short(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			fileno,
-	int			flags,
-	char			*data,
-	mach_msg_type_number_t	data_count,
-	int			*amount_written)	/* OUT */
-{
-	START_SERVER(SYS_send, 4)
-
-	arg[0] = fileno;
-	arg[1] = (integer_t)data;
-	arg[2] = (integer_t)data_count;
-	arg[3] = flags;
-	error = osend(p, arg, amount_written);
-
-	END_SERVER(SYS_send)
-}
-
-kern_return_t
-bsd_send_long(
-	mach_port_t	proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
-	int		fileno,
-	int		flags,
-	char		*data,
-	mach_msg_type_number_t	data_count,
-	int		*amount_written)	/* OUT */
-{
-	START_SERVER(SYS_send, 4)
-
-	arg[0] = fileno;
-	arg[1] = (integer_t)data;
-	arg[2] = (integer_t)data_count;
-	arg[3] = flags;
-	error = osend(p, arg, amount_written);
-
-	END_SERVER_DEALLOC(SYS_send, data, data_count)
-}
-#endif	/* COMPAT_43 */
-
-kern_return_t
-bsd_sendto_short(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			fileno,
-	int			flags,
-	sockarg_t		to,
-	mach_msg_type_number_t	tolen,
-	char			*data,
-	mach_msg_type_number_t	data_count,
-	int			*amount_written)	/* OUT */
-{
-	START_SERVER(SYS_sendmsg, 6)
-
-	arg[0] = fileno;
-	arg[1] = (integer_t)data;
-	arg[2] = (integer_t)data_count;
-	arg[3] = flags;
-	arg[4] = (integer_t)to;
-	arg[5] = tolen;
-	error = sendto(p, arg, amount_written);
-
-	END_SERVER(SYS_sendmsg)
-}
-
-kern_return_t
-bsd_sendto_long(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			fileno,
-	int			flags,
-	sockarg_t		to,
-	mach_msg_type_number_t	tolen,
-	char			*data,
-	mach_msg_type_number_t	data_count,
-	int			*amount_written)	/* OUT */
-{
-	START_SERVER(SYS_sendmsg, 6)
-
-	arg[0] = fileno;
-	arg[1] = (integer_t)data;
-	arg[2] = (integer_t)data_count;
-	arg[3] = flags;
-	arg[4] = (integer_t)to;
-	arg[5] = tolen;
-	error = sendto(p, arg, amount_written);
-
-	END_SERVER_DEALLOC(SYS_sendmsg, data, data_count)
-}
-
-#if	COMPAT_43
-kern_return_t
-bsd_recvfrom_short(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			fileno,
-	int			flags,
-	int			len,
-	sockarg_t		from,		/* pointer to OUT array */
-	mach_msg_type_number_t	*fromlen,	/* in/out */
-	char			*data,		/* pointer to OUT array */
-	mach_msg_type_number_t	*data_count)	/* out */
-{
-	START_SERVER(SYS_recvfrom, 6)
-
-	arg[0] = fileno;
-	arg[1] = (integer_t)data;
-	arg[2] = len;
-	arg[3] = flags;
-	arg[4] = (integer_t)from;
-	arg[5] = (integer_t)fromlen;
-
-	error = orecvfrom(p, arg, data_count);
-
-	END_SERVER(SYS_recvfrom)
-}
-
-kern_return_t
-bsd_recvfrom_long(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			fileno,
-	int			flags,
-	int			len,
-	sockarg_t		from,		/* pointer to OUT array */
-	mach_msg_type_number_t	*fromlen,	/* in/out */
-	char			**data,		/* out */
-	mach_msg_type_number_t	*data_count)	/* out */
-{
-	START_SERVER(SYS_recvfrom, 6)
-
-	if (vm_allocate(mach_task_self(),
-			(vm_offset_t *)data,
-			len,
-			TRUE)
-	    != KERN_SUCCESS)
-	{
-	    error = ENOBUFS;
-	} else {
-	    arg[0] = fileno;
-	    arg[1] = (integer_t)*data;
-	    arg[2] = len;
-	    arg[3] = flags;
-	    arg[4] = (integer_t)from;
-	    arg[5] = (integer_t)fromlen;
-
-	    error = orecvfrom(p, arg, data_count);
-	}
-
-	/*
-	 * Special end code to deallocate data if any error
-	 */
-        }
-	
-        unix_release();
-        error = end_server_op(p, error, interrupt);
-	if (error) {
-	    (void) vm_deallocate(mach_task_self(),
-				(vm_offset_t) *data,
-				len);
-	}
-	return (error);
-}
-#endif	/* COMPAT_43 */
-#endif /* OBSOLETE_CODE */
-
-#if	COMPAT_43 && OBSOLETE
-kern_return_t
-bsd_ocreat(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	char			*fname,
-	mach_msg_type_number_t	fname_count,
-	int			fmode,
-	int			*fileno)	/* OUT */
-{
-	START_SERVER(SYS_ocreat, 2)
-
-	TRACE(("(%s)",fname));
-	arg[0] = (integer_t)fname;
-	arg[1] = fmode;
-	error = ocreat(p, arg, fileno);
-	END_SERVER(SYS_ocreat)
-}
-#endif	/* COMPAT_43 */
-
-#if OBSOLETE
-kern_return_t
-bsd_stat(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	boolean_t		follow,
-	char			*name,
-	mach_msg_type_number_t	name_count,
-	register statb_t 	*statr)	/* out */
-{
-	struct stat	sb;
-	int stat(),lstat();
-
-	START_SERVER(follow ? SYS_stat : SYS_lstat, 2);
-
-	TRACE(("(%s)",name));
-	arg[0] = (integer_t)name;
-	arg[1] = (integer_t)&sb;
-	error = (follow?stat:lstat)(p, arg, 0);
-
-	/* copy out stat buffer... */
-	statr->s_dev	= sb.st_dev;
-	statr->s_ino	= sb.st_ino;
-	statr->s_mode	= sb.st_mode;
-	statr->s_nlink	= sb.st_nlink;
-	statr->s_uid	= sb.st_uid;
-	statr->s_gid	= sb.st_gid;
-	statr->s_rdev	= sb.st_rdev;
-	statr->s_size	= sb.st_size;
-	statr->s_atime	= sb.st_atime;
-	statr->s_mtime	= sb.st_mtime;
-	statr->s_ctime	= sb.st_ctime;
-	statr->s_blksize	= sb.st_blksize;
-	statr->s_blocks	= sb.st_blocks;
-	statr->s_flags	= sb.st_flags;
-	statr->s_gen	= sb.st_gen;
-
-	END_SERVER(follow ? SYS_stat : SYS_lstat)
-}
-#endif OBSOLETE
-
-#if OBSOLETE
-kern_return_t
-bsd_chmod(
-	mach_port_t	proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
-	char		*fname,
-	mach_msg_type_number_t	fname_count,
-	int		fmode)
-{
-	START_SERVER(SYS_chmod, 2)
-
-	TRACE(("(%s,%o)",fname,fmode));
-	arg[0] = (integer_t)fname;
-	arg[1] = fmode;
-	error =	chmod(p, arg, 0);
-
-	END_SERVER(SYS_chmod)
-}
-
-kern_return_t
-bsd_chown(
-	mach_port_t	proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
-	char		*fname,
-	mach_msg_type_number_t	fname_count,
-	int		uid,
-	int		gid)
-{
-	START_SERVER(SYS_chown, 3)
-
-	TRACE(("(%s,%d,%d)",fname,uid,gid));
-	arg[0] = (integer_t)fname;
-	arg[1] = uid;
-	arg[2] = gid;
-	error =	chown(p, arg, 0);
-
-	END_SERVER(SYS_chown)
-}
-#endif
-
-#if OBSOLETE
-kern_return_t
-bsd_truncate(
-	mach_port_t	proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t	*interrupt,
-	char		*fname,
-	mach_msg_type_number_t	fname_count,
-	int		length)
-{
-	START_SERVER(SYS_truncate, 2)
-
-	TRACE(("(%s)",fname));
-	arg[0] = (integer_t)fname;
-	arg[1] = length;
-	error = truncate(p, arg, 0);
-
-	END_SERVER(SYS_truncate)
-}
-#endif
-
-#if	COMPAT_43 && OBSOLETE
-kern_return_t
-bsd_oaccept(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
-	int			s,
-	sockarg_t		name,		/* OUT */
-	mach_msg_type_number_t	*anamelen,	/* OUT */
-	int			*new_s)		/* OUT */
-{
-	START_SERVER(SYS_accept, 3)
-
-	*anamelen = sizeof(sockarg_t);
-
-	arg[0] = s;
-	arg[1] = (integer_t) name;
-	arg[2] = (integer_t) anamelen;
-
-	error = oaccept(p, arg, new_s);
-
-	END_SERVER(SYS_accept)
-}
-#endif	/* COMPAT_43 */
-
-#if	COMPAT_43 && OBSOLETE
-kern_return_t
-bsd_osigvec(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,	/* OUT */
-	int			signo,
-	boolean_t		have_nsv,
-	struct sigvec		nsv,
-	struct sigvec		*osv,		/* OUT */
-	int			tramp)
-{
-	START_SERVER(SYS_sigvec, 4)
-
-	arg[0] = signo;
-	arg[1] = (have_nsv) ? (integer_t)&nsv : 0;
-	arg[2] = (integer_t)osv;
-	arg[3] = tramp;
-
-	{ 
-		int retval;
-		error = osigvec(p, arg, &retval);
-	}
-
-	END_SERVER(SYS_sigvec)
-}
-#endif	/* COMPAT_43 */
