@@ -686,7 +686,21 @@ void port_object_shutdown(mach_port_t port, boolean_t force)
 	 * Synchronize on seqno.
 	 * It is ok to hold locks here as the lookup does not.
 	 */
+#if OSFMACH3
+	{
+	mach_msg_type_number_t count = MACH_PORT_RECEIVE_STATUS_COUNT;
+	kr = mach_port_get_attributes(mach_task_self(),
+				      port,
+				      MACH_PORT_RECEIVE_STATUS,
+				      (mach_port_info_t) &rstatus,
+				      &count);
+	if (kr != KERN_SUCCESS)
+		panic("port_object_shutdown: m_p_get_attr: %s",
+		      mach_error_string(kr));
+	}
+#else
 	kr = mach_port_get_receive_status(mach_task_self(), port, &rstatus);
+#endif
 	assert(kr == KERN_SUCCESS);
 	while (rstatus.mps_seqno > po->seqno) {
 		condition_wait(&po->cond, &po->lock);
