@@ -40,6 +40,7 @@
 #include <sys/acct.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
+#include <bsd_1_server.h>
 
 #include <serv/syscall_subr.h>
 
@@ -76,7 +77,6 @@ int
 bsd_task_by_pid(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			pid,
 	task_t			*t,
 	mach_msg_type_name_t	*tType)
@@ -170,19 +170,17 @@ bsd_task_by_pid(
 		error = 0;
 	}
 
-	return (end_server_op(p, error, interrupt));
+	return (end_server_op(p, error, (boolean_t *)0));
 }
 
 int
 bsd_pid_by_task(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	task_t			task,
 	int			*pidp,
 	char			*comm,
-	int			*commlen,
-	integer_t		*rval)
+	mach_msg_type_number_t	*commlen)
 {
 	register struct proc *p;
 	register struct proc *sp;
@@ -207,7 +205,6 @@ bsd_pid_by_task(
 	if ((sp == 0) || (sp->p_flag & P_WEXIT)) {
 	    *pidp = 0;
 	    *commlen = 0;
-	    *rval = -1;
 	    ret = ESRCH;
 	} else {
 	    *pidp = sp->p_pid;
@@ -216,13 +213,11 @@ bsd_pid_by_task(
 		len = *commlen;
 	    bcopy(sp->p_comm, comm, len);
 	    *commlen = len;
-	    *rval = 0;
 	    /* get rid of the send right (consume on success) */
 	    (void) mach_port_deallocate(mach_task_self(), task);
 	}
 	unix_release();
 
-	*interrupt = FALSE;
 	return ret;
 }
 
@@ -280,7 +275,6 @@ int
 bsd_getrusage(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			which,
 	struct rusage		*rusage)	/* OUT */
 {
@@ -310,10 +304,10 @@ bsd_getrusage(
 		break;
 
 	default:
-		return (end_server_op(p, EINVAL, interrupt));
+		return (end_server_op(p, EINVAL, (boolean_t *)0));
 	}
 	*rusage = *rup;
-	return (end_server_op(p, 0, interrupt));
+	return (end_server_op(p, 0, (boolean_t *)0));
 }
 
 mach_error_t getrusage()
@@ -613,14 +607,12 @@ int
 bsd_take_signal(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,	/* out */
 	sigset_t		*old_mask,	/* out */
 	int			*old_onstack,	/* out */
 	int			*o_sig,		/* out */
 	integer_t		*o_code,	/* out */
 	vm_offset_t		*o_handler,	/* out */
-	vm_offset_t		*new_sp,	/* out */
-        boolean_t		*cmu_binary)    /* out */
+	vm_offset_t		*new_sp)	/* out */
 {
 	proc_invocation_t pk = get_proc_invocation();
 	register struct proc *p;
@@ -651,7 +643,7 @@ bsd_take_signal(
 	 */
 	if (p->p_stat != SRUN || (p->p_flag & P_WEXIT)) {
 	    unix_release();
-	    return (end_server_op(p, ESRCH, interrupt));
+	    return (end_server_op(p, ESRCH, (boolean_t *)0));
 	}
 
 	/*
@@ -687,7 +679,7 @@ bsd_take_signal(
 	     * No signals - return to user.
 	     */
 	    unix_release();
-	    return (end_server_op(p, 0, interrupt));
+	    return (end_server_op(p, 0, (boolean_t *)0));
 	}
 
 	action = ps->ps_sigact[sig];
@@ -753,17 +745,15 @@ bsd_take_signal(
 	}
 
 	unix_release();
-	return (end_server_op(p, 0, interrupt));
+	return (end_server_op(p, 0, (boolean_t *)0));
 }
 
 int
 bsd_sigreturn(
 	mach_port_t		proc_port,
 	mach_port_seqno_t	seqno,
-	boolean_t		*interrupt,
 	int			old_on_stack,
-	sigset_t		old_sigmask,
-        boolean_t		*cmu_binary)    /* out */
+	sigset_t		old_sigmask)
 {
 	proc_invocation_t pk = get_proc_invocation();
 	register int error;
@@ -794,7 +784,7 @@ bsd_sigreturn(
 
 	unix_release();
 
-	return (end_server_op(p, 0, interrupt));
+	return (end_server_op(p, 0, (boolean_t *)0));
 }
 
 /* FILES */
