@@ -375,7 +375,12 @@ mach_error_t server_exec_create_new_task(struct proc *p)
 	int i;
 
 	/* would it be better to use some other parent? */
-	kr = task_create(p->p_task, FALSE, &new_task);
+	kr = task_create(p->p_task,
+#if OSF_LEDGERS
+			 0, 0,
+#endif
+			 FALSE,
+			 &new_task);
 	if (kr != KERN_SUCCESS) {
 		printf("server_exec_create_new: task_create failure %x\n", kr);
 		return kr;
